@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-09-13'; # DATE
-our $VERSION = '1.22'; # VERSION
+our $DATE = '2015-09-23'; # DATE
+our $VERSION = '1.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -243,6 +243,14 @@ sub pericmd_ok {
                 argv           => [qw/1/],
                 exit_code      => 200,
             );
+            $test_run->(
+                name           => 'arg that contains dot can be handled',
+                args           => {url => '/Perinci/Examples/Tiny/Args/has_dot_args'},
+                inline_include => ['Perinci::Examples::Tiny::Args'],
+                argv           => [qw/3 7/],
+                exit_code      => 0,
+                stdout_like    => qr/^21$/,
+            );
         },
     };
 
@@ -271,7 +279,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.22 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-09-13.
+This document describes version 1.23 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-09-23.
 
 =head1 SEE ALSO
 
